@@ -1,10 +1,10 @@
 ;;; shell-command+.el --- An extended shell-command -*- lexical-binding: t -*-
 
-;; Copyright (C) 2020-2022  Free Software Foundation, Inc.
+;; Copyright (C) 2020-2023  Free Software Foundation, Inc.
 
 ;; Author: Philip Kaludercic <philipk@posteo.net>
 ;; Maintainer: Philip Kaludercic <~pkal/public-inbox@lists.sr.ht>
-;; Version: 2.4.1
+;; Version: 2.4.2
 ;; Keywords: unix, processes, convenience
 ;; Package-Requires: ((emacs "24.3"))
 ;; URL: https://git.sr.ht/~pkal/shell-command-plus
@@ -93,14 +93,12 @@
   "Prompt to use when invoking `shell-command+'."
   :type 'string)
 
-(defcustom shell-command+-default-region nil
+(defcustom shell-command+-default-region 'buffer
   "Default thing to apply a command onto.
-The default value nil will apply a buffer to the entire buffer.
 A symbol such as `line', `page', `defun', ... as defined by
 `bounds-of-thing-at-point' will restrict the region to whatever
 is specified."
-  :type '(choice (const :tag "Entire buffer" nil)
-                 (symbol :tag "Thing")))
+  :type '(symbol :tag "Thing"))
 
 
 ;;; Modular feature support
@@ -190,7 +188,9 @@ For PARSE, FORM and CONTEXT see `shell-command+-features'."
     (setf (nth 3 parse)
           (replace-regexp-in-string
            (rx (* ?\\ ?\\) (or ?\\ (group "%")))
-           buffer-file-name (nth 3 parse))))
+           (or (file-remote-p buffer-file-name 'localname)
+               buffer-file-name)
+           (nth 3 parse))))
   (list parse form context))
 
 (put #'shell-command+-expand-%
@@ -462,7 +462,7 @@ entire command."
     (insert (documentation (symbol-function 'shell-command+) 'raw))
     (dolist (feature shell-command+-features)
       (if (fboundp 'make-separator-line)
-          (insert "\n" (make-separator-line) "\n")
+          (insert "\n\n" (make-separator-line) "\n")
         (newline 2))
       (insert
        (let ((doc (get feature 'shell-command+-docstring)))
@@ -486,9 +486,14 @@ respectively be assumed as a fallback.
 
 The current configuration adds the following functionality, that
 can be combined but will be processed in the following order:"
-  (interactive (let ((bounds (and shell-command+-default-region
-                                  (bounds-of-thing-at-point
-                                   shell-command+-default-region))))
+  (interactive (let ((bounds (bounds-of-thing-at-point
+                              (or shell-command+-default-region
+                                  ;; We default to buffer for
+                                  ;; compatibility reasons, back when
+                                  ;; `shell-command+-default-region'
+                                  ;; interpreted nil as the default
+                                  ;; option to use the entire buffer.
+                                  'buffer))))
                  (list (read-shell-command
                         (if (bound-and-true-p shell-command-prompt-show-cwd)
                             (format shell-command+-prompt
